// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Sat May 02 18:23:31 +1000 2009
package com.kenai.constantine.platform;
@Deprecated
public enum TCP implements com.kenai.constantine.Constant {
TCP_MAX_SACK,
TCP_MSS,
TCP_MINMSS,
TCP_MINMSSOVERLOAD,
TCP_MAXWIN,
TCP_MAX_WINSHIFT,
TCP_MAXBURST,
TCP_MAXHLEN,
TCP_MAXOLEN,
TCP_NODELAY,
TCP_MAXSEG,
TCP_NOPUSH,
TCP_NOOPT,
TCP_KEEPALIVE,
TCP_NSTATES,
TCP_RETRANSHZ,
__UNKNOWN_CONSTANT__;
private static final ConstantResolver<TCP> resolver = 
ConstantResolver.getResolver(TCP.class, 20000, 29999);
public final int value() { return resolver.intValue(this); }
public final int intValue() { return (int) resolver.longValue(this); }
public final long longValue() { return resolver.longValue(this); }
public final String description() { return resolver.description(this); }
public final boolean defined() { return true; }
public final String toString() { return description(); }
public final static TCP valueOf(int value) { 
    return resolver.valueOf(value);
}
}
