// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2015-05-05 15:32:13 -0400
package jnr.constants.platform;
public enum Access implements jnr.constants.Constant {
F_OK,
X_OK,
W_OK,
R_OK,
__UNKNOWN_CONSTANT__;
private static final ConstantResolver<Access> resolver = 
ConstantResolver.getBitmaskResolver(Access.class);
public final int intValue() { return (int) resolver.longValue(this); }
public final long longValue() { return resolver.longValue(this); }
public final String description() { return resolver.description(this); }
public final boolean defined() { return resolver.defined(this); }
public final String toString() { return description(); }
public static Access valueOf(long value) { 
    return resolver.valueOf(value);
}
}
