// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Mon Feb 23 15:25:13 -0800 2009
package jnr.constants.platform.freebsd;
public enum TCP implements jnr.constants.Constant {
TCP_MAX_SACK(4),
TCP_MSS(512),
TCP_MINMSS(216),
TCP_MINMSSOVERLOAD(0),
TCP_MAXWIN(65535),
TCP_MAX_WINSHIFT(14),
TCP_MAXBURST(4),
TCP_MAXHLEN(60),
TCP_MAXOLEN(40),
TCP_NODELAY(1),
TCP_MAXSEG(2),
TCP_NOPUSH(4),
TCP_NOOPT(8);
// TCP_KEEPALIVE not defined
// TCP_NSTATES not defined
// TCP_RETRANSHZ not defined
private final int value;
private TCP(int value) { this.value = value; }
public static final long MIN_VALUE = 0;
public static final long MAX_VALUE = 65535;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
