// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Wed Feb 25 18:33:25 +1000 2009
package jnr.constants.platform.openbsd;
public enum TCP implements jnr.constants.Constant {
TCP_MAX_SACK(3),
TCP_MSS(512),
// TCP_MINMSS not defined
// TCP_MINMSSOVERLOAD not defined
TCP_MAXWIN(65535),
TCP_MAX_WINSHIFT(14),
TCP_MAXBURST(4),
// TCP_MAXHLEN not defined
// TCP_MAXOLEN not defined
TCP_NODELAY(1),
TCP_MAXSEG(2);
// TCP_NOPUSH not defined
// TCP_NOOPT not defined
// TCP_KEEPALIVE not defined
// TCP_NSTATES not defined
// TCP_RETRANSHZ not defined
private final int value;
private TCP(int value) { this.value = value; }
public static final long MIN_VALUE = 1;
public static final long MAX_VALUE = 65535;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
