// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2010-07-31 18:57:12 +1000
package jnr.constants.platform.darwin;
public enum NameInfo implements jnr.constants.Constant {
NI_MAXHOST(1025L),
NI_MAXSERV(32L),
NI_NOFQDN(1L),
NI_NUMERICHOST(2L),
NI_NAMEREQD(4L),
NI_NUMERICSERV(8L),
NI_DGRAM(16L),
NI_WITHSCOPEID(32L);
private final long value;
private NameInfo(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 1025L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
