// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Tue Feb 24 09:44:05 +1000 2009
package jnr.constants.platform.linux;
public enum ProtocolFamily implements jnr.constants.Constant {
PF_UNSPEC(0),
PF_LOCAL(1),
PF_UNIX(1),
PF_INET(2),
// PF_IMPLINK not defined
// PF_PUP not defined
// PF_CHAOS not defined
// PF_NS not defined
// PF_ISO not defined
// PF_OSI not defined
// PF_ECMA not defined
// PF_DATAKIT not defined
// PF_CCITT not defined
PF_SNA(22),
PF_DECnet(12),
// PF_DLI not defined
// PF_LAT not defined
// PF_HYLINK not defined
PF_APPLETALK(5),
PF_ROUTE(16),
// PF_LINK not defined
// PF_XTP not defined
// PF_COIP not defined
// PF_CNT not defined
// PF_SIP not defined
PF_IPX(4),
// PF_RTIP not defined
// PF_PIP not defined
// PF_NDRV not defined
// PF_ISDN not defined
PF_KEY(15),
PF_INET6(10),
// PF_NATM not defined
// PF_SYSTEM not defined
// PF_NETBIOS not defined
// PF_PPP not defined
// PF_ATM not defined
// PF_NETGRAPH not defined
PF_MAX(34);
private final int value;
private ProtocolFamily(int value) { this.value = value; }
public static final long MIN_VALUE = 0;
public static final long MAX_VALUE = 34;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
