// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Tue Feb 24 09:44:05 +1000 2009
package jnr.constants.platform.linux;
public enum RLIMIT implements jnr.constants.Constant {
RLIMIT_AS(9),
RLIMIT_CORE(4),
RLIMIT_CPU(0),
RLIMIT_DATA(2),
RLIMIT_FSIZE(1),
RLIMIT_LOCKS(10),
RLIMIT_MEMLOCK(8),
RLIMIT_MSGQUEUE(12),
RLIMIT_NICE(13),
RLIMIT_NLIMITS(15),
RLIMIT_NOFILE(7),
RLIMIT_NPROC(6),
RLIMIT_OFILE(7),
RLIMIT_RSS(5),
RLIMIT_RTPRIO(14),
// RLIMIT_RTTIME not defined
RLIMIT_SIGPENDING(11),
RLIMIT_STACK(3);
private final int value;
private RLIMIT(int value) { this.value = value; }
public static final long MIN_VALUE = 0;
public static final long MAX_VALUE = 15;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
