// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Mon Feb 23 15:25:12 -0800 2009
package jnr.constants.platform.freebsd;
public enum RLIM implements jnr.constants.Constant {
RLIM_NLIMITS(0xb),
RLIM_INFINITY(0xffffffff);
// RLIM_SAVED_MAX not defined
// RLIM_SAVED_CUR not defined
private final int value;
private RLIM(int value) { this.value = value; }
public static final long MIN_VALUE = 0xb;
public static final long MAX_VALUE = 0xffffffff;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
