// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Mon Dec 28 13:23:34 +0100 2009
package jnr.constants.platform.windows;
public enum OpenFlags implements jnr.constants.Constant {
O_APPEND(8),
// O_NOCTTY not defined
// O_DIRECTORY not defined
// O_EVTONLY not defined
// O_SYNC not defined
O_ACCMODE(3),
O_CREAT(256),
// O_EXLOCK not defined
O_WRONLY(1),
O_EXCL(1024),
// O_ASYNC not defined
// O_SHLOCK not defined
// O_NONBLOCK not defined
O_RDONLY(0),
O_BINARY(32768),
// O_SYMLINK not defined
// O_NOFOLLOW not defined
// O_FSYNC not defined
O_RDWR(2),
O_TRUNC(512);
private final int value;
private OpenFlags(int value) { this.value = value; }
public static final long MIN_VALUE = 0;
public static final long MAX_VALUE = 32768;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
