// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Sat May 02 18:23:30 +1000 2009
package com.kenai.constantine.platform;
@Deprecated
public enum Shutdown implements com.kenai.constantine.Constant {
SHUT_RD,
SHUT_WR,
SHUT_RDWR,
__UNKNOWN_CONSTANT__;
private static final ConstantResolver<Shutdown> resolver = 
ConstantResolver.getBitmaskResolver(Shutdown.class);
public final int value() { return resolver.intValue(this); }
public final int intValue() { return (int) resolver.longValue(this); }
public final long longValue() { return resolver.longValue(this); }
public final String description() { return resolver.description(this); }
public final boolean defined() { return true; }
public final String toString() { return description(); }
public final static Shutdown valueOf(int value) { 
    return resolver.valueOf(value);
}
}
