// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Mon Feb 23 23:19:33 +0000 2009
package jnr.constants.platform.sunos;
public enum RLIM implements jnr.constants.Constant {
RLIM_NLIMITS(0x7),
RLIM_INFINITY(0xfffffffd),
RLIM_SAVED_MAX(0xfffffffe),
RLIM_SAVED_CUR(0xffffffff);
private final int value;
private RLIM(int value) { this.value = value; }
public static final long MIN_VALUE = 0x7;
public static final long MAX_VALUE = 0xffffffff;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
