// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Mon Feb 23 15:25:14 -0800 2009
package jnr.constants.platform.freebsd;
public enum WaitFlags implements jnr.constants.Constant {
WNOHANG(0x1),
WUNTRACED(0x2),
// WSTOPPED not defined
// WEXITED not defined
WCONTINUED(0x4);
// WNOWAIT not defined
private final int value;
private WaitFlags(int value) { this.value = value; }
public static final long MIN_VALUE = 0x1;
public static final long MAX_VALUE = 0x4;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
