// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Tue Feb 24 09:44:06 +1000 2009
package jnr.constants.platform.linux;
public enum SocketOption implements jnr.constants.Constant {
SO_DEBUG(0x1),
SO_ACCEPTCONN(0x1e),
SO_REUSEADDR(0x2),
SO_KEEPALIVE(0x9),
SO_DONTROUTE(0x5),
SO_BROADCAST(0x6),
// SO_USELOOPBACK not defined
SO_LINGER(0xd),
SO_OOBINLINE(0xa),
// SO_REUSEPORT not defined
SO_TIMESTAMP(0x1d),
// SO_ACCEPTFILTER not defined
// SO_DONTTRUNC not defined
// SO_WANTMORE not defined
// SO_WANTOOBFLAG not defined
SO_SNDBUF(0x7),
SO_RCVBUF(0x8),
SO_SNDLOWAT(0x13),
SO_RCVLOWAT(0x12),
SO_SNDTIMEO(0x15),
SO_RCVTIMEO(0x14),
SO_ERROR(0x4),
SO_TYPE(0x3),
// SO_NREAD not defined
// SO_NKE not defined
// SO_NOSIGPIPE not defined
// SO_NOADDRERR not defined
// SO_NWRITE not defined
// SO_REUSESHAREUID not defined
// SO_LABEL not defined
// SO_PEERLABEL not defined
SO_ATTACH_FILTER(0x1a),
SO_BINDTODEVICE(0x19),
SO_DETACH_FILTER(0x1b),
SO_NO_CHECK(0xb),
SO_PASSCRED(0x10),
SO_PEERCRED(0x11),
SO_PEERNAME(0x1c),
SO_PRIORITY(0xc),
SO_SECURITY_AUTHENTICATION(0x16),
SO_SECURITY_ENCRYPTION_NETWORK(0x18),
SO_SECURITY_ENCRYPTION_TRANSPORT(0x17);
private final int value;
private SocketOption(int value) { this.value = value; }
public static final long MIN_VALUE = 0x1;
public static final long MAX_VALUE = 0x1e;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
