// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2010-07-31 18:57:13 +1000
package jnr.constants.platform.darwin;
public enum Sysconf implements jnr.constants.Constant {
_SC_ARG_MAX(1L),
_SC_CHILD_MAX(2L),
_SC_CLK_TCK(3L),
_SC_NGROUPS_MAX(4L),
_SC_OPEN_MAX(5L),
_SC_JOB_CONTROL(6L),
_SC_SAVED_IDS(7L),
_SC_VERSION(8L),
_SC_BC_BASE_MAX(9L),
_SC_BC_DIM_MAX(10L),
_SC_BC_SCALE_MAX(11L),
_SC_BC_STRING_MAX(12L),
_SC_COLL_WEIGHTS_MAX(13L),
_SC_EXPR_NEST_MAX(14L),
_SC_LINE_MAX(15L),
_SC_RE_DUP_MAX(16L),
_SC_2_VERSION(17L),
_SC_2_C_BIND(18L),
_SC_2_C_DEV(19L),
_SC_2_CHAR_TERM(20L),
_SC_2_FORT_DEV(21L),
_SC_2_FORT_RUN(22L),
_SC_2_LOCALEDEF(23L),
_SC_2_SW_DEV(24L),
_SC_2_UPE(25L),
_SC_STREAM_MAX(26L),
_SC_TZNAME_MAX(27L),
_SC_ASYNCHRONOUS_IO(28L),
_SC_PAGESIZE(29L),
_SC_MEMLOCK(30L),
_SC_MEMLOCK_RANGE(31L),
_SC_MEMORY_PROTECTION(32L),
_SC_MESSAGE_PASSING(33L),
_SC_PRIORITIZED_IO(34L),
_SC_PRIORITY_SCHEDULING(35L),
_SC_REALTIME_SIGNALS(36L),
_SC_SEMAPHORES(37L),
_SC_FSYNC(38L),
_SC_SHARED_MEMORY_OBJECTS(39L),
_SC_SYNCHRONIZED_IO(40L),
_SC_TIMERS(41L),
_SC_AIO_LISTIO_MAX(42L),
_SC_AIO_MAX(43L),
_SC_AIO_PRIO_DELTA_MAX(44L),
_SC_DELAYTIMER_MAX(45L),
_SC_MQ_OPEN_MAX(46L),
_SC_MAPPED_FILES(47L),
_SC_RTSIG_MAX(48L),
_SC_SEM_NSEMS_MAX(49L),
_SC_SEM_VALUE_MAX(50L),
_SC_SIGQUEUE_MAX(51L),
_SC_TIMER_MAX(52L),
_SC_NPROCESSORS_CONF(57L),
_SC_NPROCESSORS_ONLN(58L),
_SC_2_PBS(59L),
_SC_2_PBS_ACCOUNTING(60L),
_SC_2_PBS_CHECKPOINT(61L),
_SC_2_PBS_LOCATE(62L),
_SC_2_PBS_MESSAGE(63L),
_SC_2_PBS_TRACK(64L),
_SC_ADVISORY_INFO(65L),
_SC_BARRIERS(66L),
_SC_CLOCK_SELECTION(67L),
_SC_CPUTIME(68L),
_SC_FILE_LOCKING(69L),
_SC_GETGR_R_SIZE_MAX(70L),
_SC_GETPW_R_SIZE_MAX(71L),
_SC_HOST_NAME_MAX(72L),
_SC_LOGIN_NAME_MAX(73L),
_SC_MONOTONIC_CLOCK(74L),
_SC_MQ_PRIO_MAX(75L),
_SC_READER_WRITER_LOCKS(76L),
_SC_REGEXP(77L),
_SC_SHELL(78L),
_SC_SPAWN(79L),
_SC_SPIN_LOCKS(80L),
_SC_SPORADIC_SERVER(81L),
_SC_THREAD_ATTR_STACKADDR(82L),
_SC_THREAD_ATTR_STACKSIZE(83L),
_SC_THREAD_CPUTIME(84L),
_SC_THREAD_DESTRUCTOR_ITERATIONS(85L),
_SC_THREAD_KEYS_MAX(86L),
_SC_THREAD_PRIO_INHERIT(87L),
_SC_THREAD_PRIO_PROTECT(88L),
_SC_THREAD_PRIORITY_SCHEDULING(89L),
_SC_THREAD_PROCESS_SHARED(90L),
_SC_THREAD_SAFE_FUNCTIONS(91L),
_SC_THREAD_SPORADIC_SERVER(92L),
_SC_THREAD_STACK_MIN(93L),
_SC_THREAD_THREADS_MAX(94L),
_SC_TIMEOUTS(95L),
_SC_THREADS(96L),
_SC_TRACE(97L),
_SC_TRACE_EVENT_FILTER(98L),
_SC_TRACE_INHERIT(99L),
_SC_TRACE_LOG(100L),
_SC_TTY_NAME_MAX(101L),
_SC_TYPED_MEMORY_OBJECTS(102L),
_SC_V6_ILP32_OFF32(103L),
_SC_V6_ILP32_OFFBIG(104L),
_SC_V6_LP64_OFF64(105L),
_SC_V6_LPBIG_OFFBIG(106L),
_SC_IPV6(118L),
_SC_RAW_SOCKETS(119L),
_SC_SYMLOOP_MAX(120L),
_SC_ATEXIT_MAX(107L),
_SC_IOV_MAX(56L),
_SC_PAGE_SIZE(29L),
_SC_XOPEN_CRYPT(108L),
_SC_XOPEN_ENH_I18N(109L),
_SC_XOPEN_LEGACY(110L),
_SC_XOPEN_REALTIME(111L),
_SC_XOPEN_REALTIME_THREADS(112L),
_SC_XOPEN_SHM(113L),
_SC_XOPEN_STREAMS(114L),
_SC_XOPEN_UNIX(115L),
_SC_XOPEN_VERSION(116L),
_SC_XOPEN_XCU_VERSION(121L),
_SC_XBS5_ILP32_OFF32(122L),
_SC_XBS5_ILP32_OFFBIG(123L),
_SC_XBS5_LP64_OFF64(124L),
_SC_XBS5_LPBIG_OFFBIG(125L),
_SC_SS_REPL_MAX(126L),
_SC_TRACE_EVENT_NAME_MAX(127L),
_SC_TRACE_NAME_MAX(128L),
_SC_TRACE_SYS_MAX(129L),
_SC_TRACE_USER_EVENT_MAX(130L),
_SC_PASS_MAX(131L);
private final long value;
private Sysconf(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 131L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
