// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2010-07-31 18:57:12 +1000
package jnr.constants.platform.darwin;
public enum INAddr implements jnr.constants.Constant {
INADDR_ANY(0L),
INADDR_BROADCAST(0xffffffffL),
INADDR_NONE(0xffffffffL),
INADDR_LOOPBACK(0x7f000001L),
INADDR_UNSPEC_GROUP(0xe0000000L),
INADDR_ALLHOSTS_GROUP(0xe0000001L),
INADDR_ALLRTRS_GROUP(0xe0000002L),
INADDR_MAX_LOCAL_GROUP(0xe00000ffL);
private final long value;
private INAddr(long value) { this.value = value; }
public static final long MIN_VALUE = 0L;
public static final long MAX_VALUE = 0xffffffffL;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
