// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Tue Feb 24 09:44:02 +1000 2009
package jnr.constants.platform.linux;
public enum AddressFamily implements jnr.constants.Constant {
AF_UNSPEC(0),
AF_LOCAL(1),
AF_UNIX(1),
AF_INET(2),
// AF_IMPLINK not defined
// AF_PUP not defined
// AF_CHAOS not defined
// AF_NS not defined
// AF_ISO not defined
// AF_OSI not defined
// AF_ECMA not defined
// AF_DATAKIT not defined
// AF_CCITT not defined
AF_SNA(22),
AF_DECnet(12),
// AF_DLI not defined
// AF_LAT not defined
// AF_HYLINK not defined
AF_APPLETALK(5),
AF_ROUTE(16),
// AF_LINK not defined
// pseudo_AF_XTP not defined
// AF_COIP not defined
// AF_CNT not defined
// pseudo_AF_RTIP not defined
AF_IPX(4),
// AF_SIP not defined
// pseudo_AF_PIP not defined
// AF_NDRV not defined
// AF_ISDN not defined
// AF_E164 not defined
// pseudo_AF_KEY not defined
AF_INET6(10),
// AF_NATM not defined
// AF_SYSTEM not defined
// AF_NETBIOS not defined
// AF_PPP not defined
// AF_ATM not defined
// pseudo_AF_HDRCMPLT not defined
// AF_NETGRAPH not defined
AF_AX25(3),
AF_MAX(34);
private final int value;
private AddressFamily(int value) { this.value = value; }
public static final long MIN_VALUE = 0;
public static final long MAX_VALUE = 34;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
