// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2010-07-31 18:57:15 +1000
package jnr.constants.platform.fake;
public enum Shutdown implements jnr.constants.Constant {
SHUT_RD(0x1),
SHUT_WR(0x2),
SHUT_RDWR(0x4);
private final long value;
private Shutdown(long value) { this.value = value; }
public static final long MIN_VALUE = 1L;
public static final long MAX_VALUE = 0x4L;
public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
