// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2010-07-31 18:57:14 +1000
package jnr.constants.platform;
public enum RLIM implements jnr.constants.Constant {
RLIM_NLIMITS,
RLIM_INFINITY,
RLIM_SAVED_MAX,
RLIM_SAVED_CUR,
__UNKNOWN_CONSTANT__;
private static final ConstantResolver<RLIM> resolver = 
ConstantResolver.getResolver(RLIM.class, 20000, 29999);
public final int intValue() { return (int) resolver.longValue(this); }
public final long longValue() { return resolver.longValue(this); }
public final String description() { return resolver.description(this); }
public final boolean defined() { return resolver.defined(this); }
public final String toString() { return description(); }
public static RLIM valueOf(long value) { 
    return resolver.valueOf(value);
}
}
