// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Wed Feb 25 18:33:23 +1000 2009
package jnr.constants.platform.openbsd;
public enum Sysconf implements jnr.constants.Constant {
_SC_ARG_MAX(1),
_SC_CHILD_MAX(2),
_SC_CLK_TCK(3),
_SC_NGROUPS_MAX(4),
_SC_OPEN_MAX(5),
_SC_JOB_CONTROL(6),
_SC_SAVED_IDS(7),
_SC_VERSION(8),
_SC_BC_BASE_MAX(9),
_SC_BC_DIM_MAX(10),
_SC_BC_SCALE_MAX(11),
_SC_BC_STRING_MAX(12),
_SC_COLL_WEIGHTS_MAX(13),
_SC_EXPR_NEST_MAX(14),
_SC_LINE_MAX(15),
_SC_RE_DUP_MAX(16),
_SC_2_VERSION(17),
_SC_2_C_BIND(18),
_SC_2_C_DEV(19),
_SC_2_CHAR_TERM(20),
_SC_2_FORT_DEV(21),
_SC_2_FORT_RUN(22),
_SC_2_LOCALEDEF(23),
_SC_2_SW_DEV(24),
_SC_2_UPE(25),
_SC_STREAM_MAX(26),
_SC_TZNAME_MAX(27),
// _SC_ASYNCHRONOUS_IO not defined
_SC_PAGESIZE(28),
// _SC_MEMLOCK not defined
// _SC_MEMLOCK_RANGE not defined
// _SC_MEMORY_PROTECTION not defined
// _SC_MESSAGE_PASSING not defined
// _SC_PRIORITIZED_IO not defined
// _SC_PRIORITY_SCHEDULING not defined
// _SC_REALTIME_SIGNALS not defined
// _SC_SEMAPHORES not defined
_SC_FSYNC(29),
// _SC_SHARED_MEMORY_OBJECTS not defined
// _SC_SYNCHRONIZED_IO not defined
// _SC_TIMERS not defined
// _SC_AIO_LISTIO_MAX not defined
// _SC_AIO_MAX not defined
// _SC_AIO_PRIO_DELTA_MAX not defined
// _SC_DELAYTIMER_MAX not defined
// _SC_MQ_OPEN_MAX not defined
// _SC_MAPPED_FILES not defined
// _SC_RTSIG_MAX not defined
_SC_SEM_NSEMS_MAX(31),
_SC_SEM_VALUE_MAX(32),
// _SC_SIGQUEUE_MAX not defined
// _SC_TIMER_MAX not defined
// _SC_NPROCESSORS_CONF not defined
// _SC_NPROCESSORS_ONLN not defined
// _SC_2_PBS not defined
// _SC_2_PBS_ACCOUNTING not defined
// _SC_2_PBS_CHECKPOINT not defined
// _SC_2_PBS_LOCATE not defined
// _SC_2_PBS_MESSAGE not defined
// _SC_2_PBS_TRACK not defined
// _SC_ADVISORY_INFO not defined
// _SC_BARRIERS not defined
// _SC_CLOCK_SELECTION not defined
// _SC_CPUTIME not defined
// _SC_FILE_LOCKING not defined
// _SC_GETGR_R_SIZE_MAX not defined
// _SC_GETPW_R_SIZE_MAX not defined
// _SC_HOST_NAME_MAX not defined
// _SC_LOGIN_NAME_MAX not defined
// _SC_MONOTONIC_CLOCK not defined
// _SC_MQ_PRIO_MAX not defined
// _SC_READER_WRITER_LOCKS not defined
// _SC_REGEXP not defined
// _SC_SHELL not defined
// _SC_SPAWN not defined
// _SC_SPIN_LOCKS not defined
// _SC_SPORADIC_SERVER not defined
// _SC_THREAD_ATTR_STACKADDR not defined
// _SC_THREAD_ATTR_STACKSIZE not defined
// _SC_THREAD_CPUTIME not defined
// _SC_THREAD_DESTRUCTOR_ITERATIONS not defined
// _SC_THREAD_KEYS_MAX not defined
// _SC_THREAD_PRIO_INHERIT not defined
// _SC_THREAD_PRIO_PROTECT not defined
// _SC_THREAD_PRIORITY_SCHEDULING not defined
// _SC_THREAD_PROCESS_SHARED not defined
// _SC_THREAD_SAFE_FUNCTIONS not defined
// _SC_THREAD_SPORADIC_SERVER not defined
// _SC_THREAD_STACK_MIN not defined
// _SC_THREAD_THREADS_MAX not defined
// _SC_TIMEOUTS not defined
// _SC_THREADS not defined
// _SC_TRACE not defined
// _SC_TRACE_EVENT_FILTER not defined
// _SC_TRACE_INHERIT not defined
// _SC_TRACE_LOG not defined
// _SC_TTY_NAME_MAX not defined
// _SC_TYPED_MEMORY_OBJECTS not defined
// _SC_V6_ILP32_OFF32 not defined
// _SC_V6_ILP32_OFFBIG not defined
// _SC_V6_LP64_OFF64 not defined
// _SC_V6_LPBIG_OFFBIG not defined
// _SC_IPV6 not defined
// _SC_RAW_SOCKETS not defined
// _SC_SYMLOOP_MAX not defined
// _SC_ATEXIT_MAX not defined
// _SC_IOV_MAX not defined
_SC_PAGE_SIZE(28),
// _SC_XOPEN_CRYPT not defined
// _SC_XOPEN_ENH_I18N not defined
// _SC_XOPEN_LEGACY not defined
// _SC_XOPEN_REALTIME not defined
// _SC_XOPEN_REALTIME_THREADS not defined
_SC_XOPEN_SHM(30);
// _SC_XOPEN_STREAMS not defined
// _SC_XOPEN_UNIX not defined
// _SC_XOPEN_VERSION not defined
// _SC_XOPEN_XCU_VERSION not defined
// _SC_XBS5_ILP32_OFF32 not defined
// _SC_XBS5_ILP32_OFFBIG not defined
// _SC_XBS5_LP64_OFF64 not defined
// _SC_XBS5_LPBIG_OFFBIG not defined
// _SC_SS_REPL_MAX not defined
// _SC_TRACE_EVENT_NAME_MAX not defined
// _SC_TRACE_NAME_MAX not defined
// _SC_TRACE_SYS_MAX not defined
// _SC_TRACE_USER_EVENT_MAX not defined
// _SC_PASS_MAX not defined
private final int value;
private Sysconf(int value) { this.value = value; }
public static final long MIN_VALUE = 1;
public static final long MAX_VALUE = 32;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
