// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated 2010-07-31 18:57:13 +1000
package jnr.constants.platform.darwin;
public enum SocketLevel implements jnr.constants.Constant {
SOL_SOCKET(65535L);
// SOL_IP not defined
// SOL_TCP not defined
// SOL_UDP not defined
private final long value;
private SocketLevel(long value) { this.value = value; }
public static final long MIN_VALUE = 65535L;
public static final long MAX_VALUE = 65535L;

public final int intValue() { return (int) value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
