// WARNING: This file is autogenerated. DO NOT EDIT!
// Generated Mon Feb 23 15:55:17 -0800 2009
package jnr.constants.platform.freebsd;
public enum OpenFlags implements jnr.constants.Constant {
O_RDONLY(0),
O_WRONLY(1),
O_RDWR(2),
O_ACCMODE(3),
O_NONBLOCK(4),
O_APPEND(8),
O_SYNC(128),
O_SHLOCK(16),
O_EXLOCK(32),
O_ASYNC(64),
O_FSYNC(128),
O_NOFOLLOW(256),
O_CREAT(512),
O_TRUNC(1024),
O_EXCL(2048);
// O_EVTONLY not defined
// O_DIRECTORY not defined
// O_SYMLINK not defined
private final int value;
private OpenFlags(int value) { this.value = value; }
public static final long MIN_VALUE = 0;
public static final long MAX_VALUE = 2048;

public final int value() { return value; }
public final int intValue() { return value; }
public final long longValue() { return value; }
public final boolean defined() { return true; }
}
